@@ -233,7 +233,7 @@ class OccupationInsight:
 
     def __init__(self,
                  url: str = "https://solutions-api.lightcast.io/smart-dataset/occupation-insight/v1",
-                 auth_url: str = "https://solutions-api.lightcast.io/smart-dataset/occupation-insight/v1",
+                 auth_url: str = "https://solutions-api.lightcast.io/api/users/login",
                  username: str = "",
                  password: str = "",
                  insight_response: ResponseInsight = None,
@@ -276,6 +276,8 @@ class BasicOccupationInsightResponseParser(ResponseInsight):
         pass
 
     def deserialize(self, raw_response: str):
+
+        print(raw_response)
         json_response = json.loads(raw_response)
         refresh_date = json_response["date"]
 
